@@ -352,6 +352,15 @@ def any_fn(fn, coll):
     return False
 
 
+@curry(2)
+def none_fn(fn, coll):
+    for x in coll:
+        if fn(x):
+            return False
+
+    return True
+
+
 @curry(2)
 def all_pass(fx, x):
     for fn in fx:
@@ -370,6 +379,15 @@ def any_pass(fx, x):
     return False
 
 
+@curry(2)
+def none_pass(fx, x):
+    for fn in fx:
+        if fn(x):
+            return False
+
+    return True
+
+
 @curry(2)
 def none(fn, coll):
     for x in coll:
